# X509Certificate

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**subject_distinguished_name** | **str** |  | [optional] 
**issuer_distinguished_name** | **str** |  | [optional] 
**thumbprint** | **str** |  | [optional] 
**not_after** | **datetime** |  | [optional] 
**not_before** | **datetime** |  | [optional] 
**version** | **int** |  | [optional] 
**serial_number** | **str** |  | [optional] 
**signature_algorithm_name** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


